/**
    (C) Copyright 2012 Dominik Wagenfuehr

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BASEBOT_HH
#define BASEBOT_HH

class BaseBot
{
  public:
    /// Konstruktor.
    BaseBot();

    /// Destruktor.
    /**
     * Muss definiert werden, damit es bei Ableitungen
     * kein Problem gibt.
     */
    virtual ~BaseBot();

    /// Akzeptiert oder lehnt ein Angebot ab.
    /**
     * Diese Methode berechnet anhand der Strategie, ob der Wert
     * angenommen oder abgelehnt wird. Der angebotene Wert
     * muss zwischen 0 und 1000 liegen.
     * Die Methode muss von den Ableitungen implementiert werden!
     * @param value Der angebotene Wert.
     * @return true, wenn das Angebot akzeptiert wurde, ansonsten false
     */
    virtual bool acceptOffer( const int value ) = 0;

    /// Gibt die gesammelten Punkte zurueck.
    int getPoints() const;

  protected:
    /// Addiert gesammelte Punkte.
    /**
     * Die Methode ist protetected, damit nur Ableitungen
     * die Punktzahl bei einer Annahme des Angebotes
     * erhöhen können.
     */
    void addPoints( const int value );

  private:
    /// Gesammelte Punkte.
    int mPoints;
};

#endif // BASEBOT_HH
